Stan Math Library: stan/math/prim/mat/fun/promote_common.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
promote_common.hpp File Reference
`#include <stan/math/prim/mat/fun/common_type.hpp>`
`#include <stan/math/prim/mat/fun/promoter.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T1 , typename T2 , typename F >
common_type< T1, T2 >::type | stan::math::promote_common (const F &u)

[ Stan Home Page ] © 2011–2016, Stan Development Team.